==> qlcplus_4.12.3.orig.tar.xz: qlcplus-QLC-_4.12.3/plugins/udmx/src/uDMX_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="101"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation>Ce plugin offre le support de la sortie des périphériques Anyma uDMX.</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="195"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation>Souhaitez-vous redétecter le matériel&#xa0;?</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="130"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>DMX Channels</source>
        <translation>Canaux DMX</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>DMX Frame Frequency</source>
        <translation>Fréquence de trame DMX</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="156"/>
        <source>Bad</source>
        <translation>Mauvaise</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="158"/>
        <source>Good</source>
        <translation>Bonne</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="160"/>
        <source>Patch this device to a universe to find out.</source>
        <translation>Patchez ce plugin à un univers pour la découvrir.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="161"/>
        <source>System Timer Accuracy</source>
        <translation>Précision de l&apos;horloge système</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="166"/>
        <source>Unknown device</source>
        <translation>Périphérique inconnu</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="168"/>
        <source>Cannot connect to USB device.</source>
        <translation>Impossible de se connecter au périphérique USB.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.1.orig.tar.xz: qlcplus-QLC-_4.14.1/plugins/udmx/src/uDMX_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>UDMX</name>
    <message>
        <location filename="udmx.cpp" line="100"/>
        <source>This plugin provides DMX output support for Anyma uDMX devices.</source>
        <translation>Ce plugin offre le support de la sortie des périphériques Anyma uDMX.</translation>
    </message>
    <message>
        <location filename="udmx.cpp" line="199"/>
        <source>Do you wish to re-scan your hardware?</source>
        <translation>Souhaitez-vous redétecter le matériel&#xa0;?</translation>
    </message>
</context>
<context>
    <name>UDMXDevice</name>
    <message>
        <location filename="udmxdevice.cpp" line="122"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="142"/>
        <source>Device name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="144"/>
        <source>DMX Channels</source>
        <translation>Canaux DMX</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="146"/>
        <source>DMX Frame Frequency</source>
        <translation>Fréquence de trame DMX</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="149"/>
        <source>Bad</source>
        <translation>Mauvaise</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="151"/>
        <source>Good</source>
        <translation>Bonne</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="153"/>
        <source>Patch this device to a universe to find out.</source>
        <translation>Patchez ce plugin à un univers pour la découvrir.</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="154"/>
        <source>System Timer Accuracy</source>
        <translation>Précision de l&apos;horloge système</translation>
    </message>
    <message>
        <location filename="udmxdevice.cpp" line="159"/>
        <source>Device not in use</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
